@@ -1,12 +1,13 @@
 import logging
+import os
 import threading
 
 import mlflow
 
-from waveletai import constants
-from waveletai._version import VERSION as __version__
+from waveletai import constants, envs
 from waveletai.backends.hosted_backend import HostedBackend
 from waveletai.constants import ModelRegisterMode
+from waveletai.exceptions import InitFailed
 from waveletai.sessions import Session
 from waveletai.utils import MLflowModuleRegister, set_mlflow_tracing_waveletai_store
 
@@ -51,6 +52,16 @@ def init(name=None, pwd=None, backend=None, api_token=None):
         # return session
 
 
+def _get_backend():
+    global _backend
+    if _backend:
+        return _backend
+    if _backend is None and os.getenv(envs.API_TOKEN):
+        return init()
+    else:
+        raise InitFailed()
+
+
 def close():
     global _backend
     if _backend:
@@ -65,8 +76,7 @@ def create_app(name, tags=[], desc=None):
     :param desc :str 应用说明
     :return: App对象
     """
-    global _backend
-    return _backend.create_app(name, tags, desc)
+    return _get_backend().create_app(name, tags, desc)
 
 
 def get_app(app_id):
@@ -75,8 +85,7 @@ def get_app(app_id):
     :param app_id: 应用ID
     :return: App对象
     """
-    global _backend
-    return _backend.get_app(app_id)
+    return _get_backend().get_app(app_id)
 
 
 def create_dataset(name, zone, path, data_type=constants.DataType.TYPE_FILE.value, desc=None):
@@ -89,8 +98,7 @@ def create_dataset(name, zone, path, data_type=constants.DataType.TYPE_FILE.valu
     :param desc: 数据集详情
     :return: Dataset对象
     """
-    global _backend
-    return _backend.create_dataset(name, zone, path, data_type, desc)
+    return _get_backend().create_dataset(name, zone, path, data_type, desc)
 
 
 def get_dataset(dataset_id):
@@ -99,8 +107,7 @@ def get_dataset(dataset_id):
     :param dataset_id:数据集ID
     :return: Dataset对象
     """
-    global _backend
-    return _backend.get_dataset(dataset_id)
+    return _get_backend().get_dataset(dataset_id)
 
 
 def download_dataset_artifact(dataset_id, path, destination):
@@ -111,20 +118,19 @@ def download_dataset_artifact(dataset_id, path, destination):
     :param destination:本地存储路径
     :return:
     """
-    global _backend
-    return _backend.download_dataset_artifact(dataset_id, path, destination)
+    return _get_backend().download_dataset_artifact(dataset_id, path, destination)
 
 
-def download_dataset_artifacts(data_id, destination, unzip=False):
+def download_dataset_artifacts(data_id, destination, unzip=False, imgtype=None):
     """
     下载数据集/特征库全部文件到本地指定目录
     :param data_id:数据集ID/特征库ID
     :param destination:本地存储路径
     :param unzip:仅当当前数据ID为特征库ID时生效，是否自动解压zip数据，默认为不解压
+    :param imgtype: 特征库图片类型 pascal_voc/coco
     :return:
     """
-    global _backend
-    return _backend.download_dataset_artifacts(data_id, destination, unzip)
+    return _get_backend().download_dataset_artifacts(data_id, destination, unzip, imgtype)
 
 
 def upload_dataset_artifacts(dataset_id, path):
@@ -134,8 +140,7 @@ def upload_dataset_artifacts(dataset_id, path):
     :param path: 要上传的文件夹/文件路径
     :return:  上传文件 succ，共xxx个
     """
-    global _backend
-    return _backend.upload_dataset_artifacts(dataset_id, path)
+    return _get_backend().upload_dataset_artifacts(dataset_id, path)
 
 
 def create_model(name, app_id, desc=None, auth_id=None, git_url=None, http_url=None):
@@ -149,8 +154,7 @@ def create_model(name, app_id, desc=None, auth_id=None, git_url=None, http_url=N
     :param app_id:所属应用ID
     :return:
     """
-    global _backend
-    return _backend.create_model(name, app_id, desc, auth_id, git_url, http_url)
+    return _get_backend().create_model(name, app_id, desc, auth_id, git_url, http_url)
 
 
 def get_model(model_id):
@@ -159,8 +163,7 @@ def get_model(model_id):
     :param model_id:模型ID
     :return:
     """
-    global _backend
-    return _backend.get_model(model_id)
+    return _get_backend().get_model(model_id)
 
 
 def register_model_version(model_id, desc, artifacts, mode=ModelRegisterMode.PYFUNC.value):
@@ -172,8 +175,7 @@ def register_model_version(model_id, desc, artifacts, mode=ModelRegisterMode.PYF
     :param mode: 注册模式,默认为自定义(ModelRegisterMode.PYFUNC.value)
     :return:
     """
-    global _backend
-    return _backend.register_model_version(model_id, desc, artifacts, mode)
+    return _get_backend().register_model_version(model_id, desc, artifacts, mode)
 
 
 def get_model_version_by_model(model_id, version):
@@ -183,8 +185,7 @@ def get_model_version_by_model(model_id, version):
     :param version:模型版本号
     :return:
     """
-    global _backend
-    return _backend.get_model_version(model_id, version)
+    return _get_backend().get_model_version(model_id, version)
 
 
 def get_model_version_by_id(model_version_id):
@@ -193,8 +194,7 @@ def get_model_version_by_id(model_version_id):
     :param model_version_id:模型库ID
     :return:
     """
-    global _backend
-    return _backend.get_repo_by_repo_id(model_version_id)
+    return _get_backend().get_repo_by_repo_id(model_version_id)
 
 
 def list_models(app_id):
@@ -203,8 +203,7 @@ def list_models(app_id):
     :param app_id:模型ID
     :return:
     """
-    global _backend
-    return _backend.list_models(app_id)
+    return _get_backend().list_models(app_id)
 
 
 def update_dataset(dataset_id, name, zone, desc=None):
@@ -216,8 +215,7 @@ def update_dataset(dataset_id, name, zone, desc=None):
     :param desc:
     :return:
     """
-    global _backend
-    return _backend.update_dataset(dataset_id, name, zone, desc)
+    return _get_backend().update_dataset(dataset_id, name, zone, desc)
 
 
 def delete_dataset(dataset_id):
@@ -226,8 +224,7 @@ def delete_dataset(dataset_id):
     :param dataset_id:
     :return:
     """
-    global _backend
-    return _backend.delete_dataset(dataset_id)
+    return _get_backend().delete_dataset(dataset_id)
 
 
 def update_model(model_id, app_id, name, desc=None):
@@ -239,8 +236,7 @@ def update_model(model_id, app_id, name, desc=None):
     :param desc:
     :return:
     """
-    global _backend
-    return _backend.update_model(model_id, app_id, name, desc)
+    return _get_backend().update_model(model_id, app_id, name, desc)
 
 
 def delete_model(model_id):
@@ -249,8 +245,7 @@ def delete_model(model_id):
     :param model_id:
     :return:
     """
-    global _backend
-    return _backend.delete_model(model_id)
+    return _get_backend().delete_model(model_id)
 
 
 def list_model_versions(model_id):
@@ -259,8 +254,7 @@ def list_model_versions(model_id):
     :param model_id:
     :return:
     """
-    global _backend
-    return _backend.list_model_versions(model_id)
+    return _get_backend().list_model_versions(model_id)
 
 
 def abandon_model_version(model_id, version):
@@ -270,8 +264,7 @@ def abandon_model_version(model_id, version):
     :param version:
     :return:
     """
-    global _backend
-    return _backend.abandon_model_version(model_id, version)
+    return _get_backend().abandon_model_version(model_id, version)
 
 
 def update_model_version(model_id, version, desc=None):
@@ -282,8 +275,7 @@ def update_model_version(model_id, version, desc=None):
     :param version:
     :return:
     """
-    global _backend
-    return _backend.update_model_version(model_id, version, desc)
+    return _get_backend().update_model_version(model_id, version, desc)
 
 
 def list_experiments(model_id):
@@ -292,8 +284,7 @@ def list_experiments(model_id):
     :param model_id:
     :return:
     """
-    global _backend
-    return _backend.list_experiments(model_id)
+    return _get_backend().list_experiments(model_id)
 
 
 def download_model_version_asset(repo_id, path, destination):
@@ -304,8 +295,7 @@ def download_model_version_asset(repo_id, path, destination):
     :param destination:
     :return:
     """
-    global _backend
-    return _backend.download_model_version_asset(repo_id, path, destination)
+    return _get_backend().download_model_version_asset(repo_id, path, destination)
 
 
 def download_model_version_artifacts(repo_id, destination):
@@ -315,8 +305,7 @@ def download_model_version_artifacts(repo_id, destination):
     :param destination:
     :return:
     """
-    global _backend
-    return _backend.download_model_version_artifacts(repo_id, destination)
+    return _get_backend().download_model_version_artifacts(repo_id, destination)
 
 
 def list_model_releases(model_id, version):
@@ -326,8 +315,7 @@ def list_model_releases(model_id, version):
     :param version: 默认为None
     :return:
     """
-    global _backend
-    return _backend.list_model_releases(model_id, version)
+    return _get_backend().list_model_releases(model_id, version)
 
 
 def list_model_releases_by_repo(repo_id):
@@ -336,11 +324,10 @@ def list_model_releases_by_repo(repo_id):
     :param repo_id:
     :return:
     """
-    global _backend
-    return _backend.list_model_releases_by_repo(repo_id)
+    return _get_backend().list_model_releases_by_repo(repo_id)
 
 
-def create_experiment(name, model_id, params=None, desc=None, ):
+def create_experiment(name, model_id, desc=None, ):
     """
     创建实验
     :param name:模型名称
@@ -349,11 +336,10 @@ def create_experiment(name, model_id, params=None, desc=None, ):
     :param params: 参数字典{key:value, ...}
     :return:
     """
-    global _backend
-    return _backend.create_experiment(name=name, model_id=model_id, params=params, host_id=None,
-                                      dataset_id=None, feature_id=None, is_train=True, desc=desc,
-                                      mlexp_id=None, artifact_location=None, online_train=False,
-                                      docker_args={})
+    return _get_backend().create_experiment(name=name, model_id=model_id, params=None, host_id=None,
+                                            dataset_id=None, feature_id=None, is_train=True, desc=desc,
+                                            mlexp_id=None, artifact_location=None, online_train=False,
+                                            docker_args={})
 
 
 @set_mlflow_tracing_waveletai_store
@@ -363,8 +349,7 @@ def get_experiment(experiment_id):
     :param experiment_id:实验ID
     :return:
     """
-    global _backend
-    return _backend.get_experiment(experiment_id)
+    return _get_backend().get_experiment(experiment_id)
 
 
 def get_experiment_by_mlflow_experiment(experiment_id):
@@ -372,8 +357,7 @@ def get_experiment_by_mlflow_experiment(experiment_id):
     根据mlexperiment id 查询wai experiment
     :return:
     """
-    global _backend
-    return _backend.get_experiment_by_mlflow_experiment(experiment_id)
+    return _get_backend().get_experiment_by_mlflow_experiment(experiment_id)
 
 
 def get_experiment_by_mlflow_run(run_id):
@@ -382,8 +366,7 @@ def get_experiment_by_mlflow_run(run_id):
     :param run_id:
     :return:
     """
-    global _backend
-    return _backend.get_experiment_by_mlflow_run(run_id)
+    return _get_backend().get_experiment_by_mlflow_run(run_id)
 
 
 @set_mlflow_tracing_waveletai_store
@@ -454,13 +437,12 @@ def set_tags(tags):
 def download_feature_zip(feature_id, destination, unzip=False):
     """
     通过特征id下载特征zip包到本地指定目录
-    :param unzip: 是否解压 默认不解压
     :param feature_id:特征id
     :param destination:本地存储地址 默认空
+    :param unzip: 是否解压 默认不解压
     :return:
     """
-    global _backend
-    return _backend.download_feature_zip(feature_id, destination, unzip)
+    return _get_backend().download_feature_zip(feature_id, destination, unzip)
 
 
 def upload_artifact(local_file, artifact_path, run_id):
@@ -471,8 +453,7 @@ def upload_artifact(local_file, artifact_path, run_id):
     :param run_id:
     :return:
     """
-    global _backend
-    return _backend.upload_artifact(local_file, artifact_path, run_id)
+    return _get_backend().upload_artifact(local_file, artifact_path, run_id)
 
 
 @set_mlflow_tracing_waveletai_store
