@@ -23,7 +23,6 @@ from waveletai.envs import CHUNK_SIZE, WARN_SIZE
 from multiprocessing.dummy import Pool
 from waveletai.backend import Backend
 from waveletai.utils import with_api_exceptions_handler
-from waveletai.oauth import WaveletAIAuthenticator
 from waveletai.dataset import Dataset, Asset
 from waveletai.feature import Feature
 from waveletai.model import ModelVersion
@@ -317,7 +316,7 @@ class HostedBackend(Backend):
         headers = {'User-Agent': user_agent}
         if api_token is None:
             res = self._session.post(
-                url=f'{self.api_address}/account/users/login/',
+                url=f'{self.api_address}/account/users/login/jwt/',
                 json={'username': name, 'password': pwd},
                 headers=headers,
             )
@@ -328,16 +327,13 @@ class HostedBackend(Backend):
             api_token = data["token"]
             user_id = data['user_id']
             os.environ.update({
-                envs.API_TOKEN: api_token,
                 'LOGNAME': user_id
             })
-        elif len(api_token) > 32:
+        else:
             # api-token登录
             try:
                 od = json.loads(base64.b64decode(api_token).decode('utf-8'))
-                os.environ.update({
-                    envs.API_URL: od['api_url']
-                })
+                os.environ.update({envs.API_URL: od['api_url']})
             except Exception as e:
                 raise InvalidAPIToken()
             res = self._session.post(
@@ -349,10 +345,9 @@ class HostedBackend(Backend):
                 raise LoginFailed(res.json()["message"])
             print("WaveletAI Backend connected")
             data = res.json()['data']
-            api_token = data["token"]
+            api_token = 'Bearer ' + data["token"]
             user_id = data['user_id']
             os.environ.update({
-                envs.API_TOKEN: api_token,
                 'LOGNAME': user_id
             })
 
@@ -369,10 +364,6 @@ class HostedBackend(Backend):
                 os.environ.pop(k)
         self._session.close()
 
-    @with_api_exceptions_handler
-    def _create_authenticator(self, api_token, ssl_verify):
-        return WaveletAIAuthenticator(api_token, ssl_verify)
-
     @property
     def api_address(self):
         api_url = os.getenv(envs.API_URL)
@@ -631,11 +622,12 @@ class HostedBackend(Backend):
             raise e
 
     @with_api_exceptions_handler
-    def download_dataset_artifacts(self, data_id, destination, unzip):
+    def download_dataset_artifacts(self, data_id, destination, unzip, imgtype=None):
         """
         :param data_id:
         :param destination:
         :param unzip:
+        :param imgtype:
         :return:
         """
         dataset = self.get_dataset(data_id)
@@ -646,7 +638,7 @@ class HostedBackend(Backend):
             self.download_dataset_artifacts_(data_id, dataset_type, name, destination)
         else:
             feature = self.get_feature(data_id)
-            self._download_feature_zip(data_id, destination, unzip)
+            self._download_feature_zip(data_id, destination, unzip, imgtype)
             if feature is None:
                 raise Exception('需下载的数据集/特征库ID未找到，请检查后重新尝试')
 
@@ -761,19 +753,19 @@ class HostedBackend(Backend):
             return e
 
     @with_api_exceptions_handler
-    def create_model(self, app_id, name, desc, auth_id, git_url, http_url):
+    def create_model(self, name, app_id, desc, auth_id, git_url, http_url):
         """
         当前应用下创建模型
-        :param app_id: 应用ip
-        :param http_url: http地址 默认空
+        :param name:模型名称
+        :param app_id: 应用id
+        :param desc:模型备注
         :param auth_id: auth_id 默认空
         :param git_url: git地址 默认空
-        :param name:模型名称
-        :param desc:模型备注
+        :param http_url: http地址 默认空
         :return: List of Class `Model` Object
         """
-        res = self._session.post(url=f'{self.api_address}/training/model/', json={"app_id": app_id,
-                                                                                  "name": name,
+        res = self._session.post(url=f'{self.api_address}/training/model/', json={"name": name,
+                                                                                  "app_id": app_id,
                                                                                   "desc": desc,
                                                                                   "auth_id": auth_id,
                                                                                   "git_url": git_url,
@@ -830,8 +822,7 @@ class HostedBackend(Backend):
         )
         dict = res.json()['data']
         return ModelVersion(self, dict['id'], dict['version'], dict['desc'], dict['model_id'], dict['model_name'],
-                            dict['mode'], dict['create_user_name'], dict['create_time'], dict['create_user_id'],
-                            dict['json_data'])
+                            dict['mode'], dict['create_user_name'], dict['create_time'], dict['create_user_id'])
 
     @with_api_exceptions_handler
     def download_model(self, model_id, version, destination):
@@ -1067,8 +1058,10 @@ class HostedBackend(Backend):
                             data['create_user_name'], data['create_time'], data['create_user_id'], data['mode'])
 
     @with_api_exceptions_handler
-    def _get_feature_zip_path(self, feature_id):
-        res = self._session.get(url=f'{self.api_address}/data/feature/{feature_id}/asset')
+    def _get_feature_zip_path(self, feature_id, imgtype):
+        if imgtype == None:
+            imgtype = ''
+        res = self._session.get(url=f'{self.api_address}/data/feature/{feature_id}/asset?type={imgtype}')
         if res.json()["message"]:
             raise Exception(res.json()["message"])
         data = res.json()['data']
@@ -1078,11 +1071,12 @@ class HostedBackend(Backend):
         return feature_path
 
     @with_api_exceptions_handler
-    def _download_feature_zip(self, feature_id, destination, unzip):
+    def _download_feature_zip(self, feature_id, destination, unzip, imgtype):
         """
-        :param unzip: 是否解压
         :param feature_id:特征id
         :param destination:本地存储路径
+        :param type:特征库zip类型
+        :param unzip: 是否解压
         :return:
         """
         if not destination:
@@ -1092,7 +1086,7 @@ class HostedBackend(Backend):
             os.makedirs(destination)
         elif not os.path.isdir(destination):
             raise NotADirectory(destination)
-        feature_path = self._get_feature_zip_path(feature_id)
+        feature_path = self._get_feature_zip_path(feature_id, imgtype)
         if feature_path is None:
             return '该特征下无可下载资源'
         try:
