@@ -58,6 +58,12 @@ class WaveletAIException(Exception):
     pass
 
 
+class InitFailed(WaveletAIException):
+    def __init__(self):
+        super(InitFailed, self).__init__('Initialization failed. Please set the environment variable of WAVELETAI_TOKEN'
+                                         ' or invoke the waveletai.init() method on manual before use waveletai sdk')
+
+
 class SSLError(WaveletAIException):
     def __init__(self):
         super(SSLError, self).__init__('SSL certificate validation failed. Set WaveletAI_ALLOW_SELF_SIGNED_CERTIFICATE '
