@@ -8,7 +8,9 @@
 @File    : __init__.py
 @Desc    :
 """
+import functools
 
+import mlflow
 import requests
 from waveletai.exceptions import ConnectionLost, Forbidden, ServerError, Unauthorized, SSLError
 from bravado.exception import BravadoConnectionError, BravadoTimeoutError, HTTPForbidden, \
@@ -139,3 +141,21 @@ def with_api_exceptions_handler(func):
         raise ConnectionLost()
 
     return wrapper
+
+
+class MLflowModuleRegister:
+    def __init__(self, model_name):
+        self.model = model_name
+
+    def __getattr__(self, item):
+        _m = getattr(mlflow, self.model)
+        return getattr(_m, item)
+
+
+def set_mlflow_tracing_waveletai_store(func):
+    @functools.wraps(func)
+    def wrapper(*args, **kwargs):
+        mlflow.set_tracking_uri('waveletai-store://')
+        return func(*args, **kwargs)
+
+    return wrapper
