@@ -290,6 +290,31 @@ def upload_to_storage(upload_entries, upload_api_fun, upload_chunk_api_fun, mode
         progress_indicator.progress(curr_size)
     progress_indicator.complete()
 
+def dataset_upload_to_storage(upload_entries, upload_api_fun, upload_chunk_api_fun, dataset_id, warn_limit=None):
+    unique_upload_entries = scan_upload_entries(upload_entries)
+    total_size = 0
+    for entry in unique_upload_entries:
+        if not entry.is_stream():
+            total_size += os.path.getsize(entry.source_path)
+    progress_indicator = SilentProgressIndicator(total_size)
+    if warn_limit is not None and total_size >= warn_limit:
+            progress_indicator = LoggingProgressIndicator(total_size)
+    s_count = f_count = 0
+    for entry in unique_upload_entries:
+        curr_size = os.path.getsize(entry.source_path)
+        if os.path.getsize(entry.source_path) > WARN_SIZE:
+            res = upload_chunk_api_fun(
+                **dict(entry=entry, dataset_id=dataset_id))
+        else:
+            res = upload_api_fun(
+                **dict(entry=entry, dataset_id=dataset_id))
+        if res:
+            s_count = s_count + 1
+        else:
+            f_count = f_count + 1
+        progress_indicator.progress(curr_size)
+    progress_indicator.complete()
+
 # def upload_to_storage(upload_entries, upload_api_fun, upload_tar_api_fun, warn_limit=None, **kwargs):
 #     unique_upload_entries = scan_upload_entries(upload_entries)
 #     progress_indicator = SilentProgressIndicator()
